@@ -5,39 +5,57 @@ sentry.web.forms.projects
 :copyright: (c) 2010-2013 by the Sentry Team, see AUTHORS for more details.
 :license: BSD, see LICENSE for more details.
 """
-import itertools
 from django import forms
+from django.conf import settings
 from django.contrib.auth import authenticate
 from django.utils.translation import ugettext_lazy as _
-from sentry.constants import EMPTY_PASSWORD_VALUES
+
+from sentry.constants import EMPTY_PASSWORD_VALUES, TAG_LABELS
 from sentry.models import Project, ProjectOption, User
 from sentry.permissions import can_set_public_projects
 from sentry.web.forms.fields import (
-    RadioFieldRenderer, UserField, OriginsField, RangeField, get_team_choices)
+    UserField, OriginsField, RangeField, get_team_choices)
 
 
 BLANK_CHOICE = [("", "")]
 
 
 class ProjectTagsForm(forms.Form):
-    filters = forms.MultipleChoiceField(choices=(), widget=forms.CheckboxSelectMultiple(), required=False)
+    filters = forms.MultipleChoiceField(
+        choices=(), widget=forms.CheckboxSelectMultiple(), required=False)
+    annotations = forms.MultipleChoiceField(
+        choices=(), widget=forms.CheckboxSelectMultiple(), required=False)
 
     def __init__(self, project, tag_list, *args, **kwargs):
         self.project = project
         super(ProjectTagsForm, self).__init__(*args, **kwargs)
 
-        self.fields['filters'].choices = tuple(
-            (k, '%s (%s)' % (k.replace('_', ' ').title(), k))
-            for k in itertools.imap(unicode, tag_list)
-        )
-        self.fields['filters'].widget.choices = self.fields['filters'].choices
+        tag_choices = []
+        for tag in tag_list:
+            tag_choices.append(
+                (tag, TAG_LABELS.get(tag) or tag.replace(u'_', u' ').title())
+            )
 
-        enabled_tags = ProjectOption.objects.get_value(self.project, 'tags', tag_list)
-        self.fields['filters'].initial = enabled_tags
+        for field in ('filters', 'annotations'):
+            self.fields[field].choices = tag_choices
+            self.fields[field].widget.choices = self.fields[field].choices
+
+        enabled_filters = ProjectOption.objects.get_value(
+            self.project, 'tags', tag_list)
+        self.fields['filters'].initial = enabled_filters
+
+        enable_annotations = ProjectOption.objects.get_value(
+            self.project, 'annotations', ['sentry:user'])
+        self.fields['annotations'].initial = enable_annotations
 
     def save(self):
         filters = self.cleaned_data.get('filters')
-        ProjectOption.objects.set_value(self.project, 'tags', filters)
+        ProjectOption.objects.set_value(
+            self.project, 'tags', filters)
+
+        annotations = self.cleaned_data.get('annotations')
+        ProjectOption.objects.set_value(
+            self.project, 'annotations', annotations)
 
 
 class BaseProjectForm(forms.ModelForm):
@@ -64,38 +82,17 @@ class NewProjectAdminForm(NewProjectForm):
 
 
 class RemoveProjectForm(forms.Form):
-    removal_type = forms.ChoiceField(choices=(
-        ('1', _('Remove all attached events.')),
-        ('2', _('Migrate events to another project.')),
-        # ('3', _('Hide this project.')),
-    ), widget=forms.RadioSelect(renderer=RadioFieldRenderer))
-    project = forms.ChoiceField(choices=(), required=False)
-    password = forms.CharField(label=_("Password"), widget=forms.PasswordInput, help_text=_("Confirm your identity by entering your password."))
+    password = forms.CharField(
+        label=_("Password"), widget=forms.PasswordInput,
+        help_text=_("Confirm your identity by entering your password."))
 
-    def __init__(self, user, project_list, *args, **kwargs):
+    def __init__(self, user, *args, **kwargs):
         super(RemoveProjectForm, self).__init__(*args, **kwargs)
         self.user = user
-        if not project_list:
-            del self.fields['project']
-            self.fields['removal_type'].choices = filter(lambda x: x[0] != '2', self.fields['removal_type'].choices)
-        else:
-            self.fields['project'].choices = [(p.pk, p.name) for p in project_list]
-            self.fields['project'].widget.choices = self.fields['project'].choices
-
         # HACK: don't require current password if they don't have one
         if self.user.password in EMPTY_PASSWORD_VALUES:
             del self.fields['password']
 
-    def clean(self):
-        data = self.cleaned_data
-        if data.get('removal_type') == 2 and not data.get('project'):
-            raise forms.ValidationError(_('You must select a project to migrate data'))
-        return data
-
-    def clean_project(self):
-        project_id = self.cleaned_data['project']
-        return Project.objects.get_from_cache(id=project_id)
-
     def clean_password(self):
         """
         Validates that the old_password field is correct.
@@ -169,3 +166,42 @@ class NotificationTagValuesForm(forms.Form):
 
     def clean_values(self):
         return set(filter(bool, self.cleaned_data.get('values').split(',')))
+
+
+class ProjectQuotasForm(forms.Form):
+    per_minute = forms.CharField(
+        label=_('Maximum events per minute'),
+        widget=forms.TextInput(attrs={'placeholder': 'e.g. 90% or 100'}),
+        help_text=_('This cannot be higher than the team (or system) allotted maximum. The value can be either a fixed number, or a percentage that is relative to the team\'s overall quota.'),
+        required=False
+    )
+
+    def __init__(self, project, *args, **kwargs):
+        self.project = project
+        super(ProjectQuotasForm, self).__init__(*args, **kwargs)
+        per_minute = ProjectOption.objects.get_value(
+            self.project, 'quotas:per_minute', None
+        )
+        if per_minute is None:
+            per_minute = settings.SENTRY_DEFAULT_MAX_EVENTS_PER_MINUTE
+        self.fields['per_minute'].initial = per_minute
+
+    def clean_per_minute(self):
+        value = self.cleaned_data.get('per_minute')
+        if not value:
+            return value
+        if value.endswith('%'):
+            try:
+                pct = int(value[:-1])
+            except (TypeError, ValueError):
+                raise forms.ValidationError('Invalid percentage')
+            if pct > 100:
+                raise forms.ValidationError('Invalid percentage')
+            if pct == 0:
+                value = '0'
+        return value
+
+    def save(self):
+        ProjectOption.objects.set_value(
+            self.project, 'quotas:per_minute', self.cleaned_data['per_minute'] or ''
+        )
