@@ -12,7 +12,7 @@ from django.http import HttpResponseRedirect
 from django.views.decorators.csrf import csrf_protect
 from django.utils.translation import ugettext as _
 
-from sentry.constants import MEMBER_USER, MEMBER_OWNER
+from sentry.constants import MEMBER_USER, MEMBER_OWNER, STATUS_VISIBLE
 from sentry.models import PendingTeamMember, TeamMember, AccessGroup, User
 from sentry.permissions import (
     can_add_team_member, can_remove_team, can_create_projects,
@@ -156,8 +156,10 @@ def manage_team_projects(request, team):
     if result is False and not request.user.has_perm('sentry.can_change_team'):
         return HttpResponseRedirect(reverse('sentry'))
 
-    project_list = list(team.project_set.all())
-    project_list.sort(key=lambda o: o.slug)
+    project_list = team.project_set.all()
+    if not request.user.is_superuser:
+        project_list = project_list.filter(status=STATUS_VISIBLE)
+    project_list = sorted(project_list, key=lambda o: o.slug)
     for project in project_list:
         project.team = team
 
@@ -303,8 +305,11 @@ def edit_team_member(request, team, member_id):
     except TeamMember.DoesNotExist:
         return HttpResponseRedirect(reverse('sentry-manage-team', args=[team.slug]))
 
+    if member.user == team.owner:
+        return HttpResponseRedirect(reverse('sentry-manage-team', args=[team.slug]))
+
     if not can_edit_team_member(request.user, member):
-        return HttpResponseRedirect(reverse('sentry'))
+        return HttpResponseRedirect(reverse('sentry-manage-team', args=[team.slug]))
 
     form = EditTeamMemberForm(team, request.POST or None, instance=member)
     if form.is_valid():
